@@ -13,6 +13,23 @@ from requests import Response
 logger = logging.getLogger(__name__)
 
 
+def handle_retrieve_state_response(response: Response) -> Any:
+    """
+     Checks status codes and converts JSON string to Python objects. Returns empty list if no result was found.
+    """
+    if response.status_code == HTTPStatus.NOT_FOUND:
+        return {}
+
+    check_status_code(response)
+
+    try:
+        return json.loads(response.content)
+    except JSONDecodeError:
+        message = 'File is not correctly JSON formatted.'
+        logger.error(message)
+        raise ValueError(message) from JSONDecodeError
+
+
 def handle_download_response(response: Response) -> Any:
     """
      Checks status codes and converts JSON string to Python objects. Returns empty list if no result was found.
