@@ -1,6 +1,7 @@
 """
 Osiris-ingress API.
 """
+import json
 import logging
 from typing import Any
 
@@ -104,15 +105,15 @@ class Ingress:
 
         check_upload_status_code(response)
 
-    def save_state(self, file):
+    def save_state(self, state):
         """
         Uploads the state file to <dataset_guid>. Can be downloaded from end-point in egress.
 
-        :param file: File to be uploaded to <dataset_guid> and stored as state.json.
+        :param state: The json data to be saved in <dataset_guid> and stored as state.json.
         """
         response = requests.post(
             url=f'{self.ingress_url}/{self.dataset_guid}/save_state',
-            files={'file': file},
+            files={'file': json.dumps(state)},
             headers={'Authorization': self.client_auth.get_access_token()}
         )
 
@@ -120,8 +121,10 @@ class Ingress:
 
     def retrieve_state(self) -> Any:
         """
-         Download state.json file from data storage from the given guid. This endpoint expects state.json to be
-         stored in the folder {guid}/'.
+        Download state.json file from data storage from the given guid.
+        The endpoint will return empty dict {} if state.json does not exist.
+
+        :returns: json-data from state.json.
         """
         response = requests.get(
             url=f'{self.ingress_url}/{self.dataset_guid}/retrieve_state',
